/*
 * Accountable object support.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "accountable.h"



Accountable::~Accountable()
{
}

/* Attach to the object. */

void Accountable::attach()
{
    std::lock_guard<std::mutex> guard(_attached_lock);

    _attached += 1;
}

/* Detach from the object. */

unsigned int Accountable::detach()
{
    std::lock_guard<std::mutex> guard(_attached_lock);

    if (_attached)
        _attached -= 1;

    return _attached;
}

// vim: tabstop=4 expandtab shiftwidth=4
